HTMHtmNodeContext class final

Context struct passed to visitor callbacks.

Inheritance
Implemented types
Available extensions

Constructors

HTMHtmNodeContext()

Properties

address Pointer<T>

Available on T, provided by the StructAddress extension

The memory address of the underlying data.
no setter
depth int
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
indexInParent int
getter/setter pair
isInline int
getter/setter pair
nodeType int
getter/setter pair
parentTag Pointer<Utf8>
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
tagName Pointer<Utf8>
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited