ConversionOptions class
Constructors
-
ConversionOptions({HeadingStyle headingStyle = HeadingStyle.atx, ListIndentType listIndentType = ListIndentType.spaces, int listIndentWidth = 2, String bullets = '-', String strongEmSymbol = '*', bool escapeAsterisks = true, bool escapeUnderscores = true, bool escapeMisc = false, bool escapeAscii = false, String codeLanguage = '', bool autolinks = true, bool defaultTitle = false, bool brInTables = false, HighlightStyle highlightStyle = HighlightStyle.standard, bool extractMetadata = false, WhitespaceMode whitespaceMode = WhitespaceMode.normal, bool stripNewlines = false, bool wrap = false, int wrapWidth = 80, bool convertAsInline = false, String subSymbol = '~', String supSymbol = '^', NewlineStyle newlineStyle = NewlineStyle.lf, CodeBlockStyle codeBlockStyle = CodeBlockStyle.fenced, List<
String> keepInlineImagesIn = const [], PreprocessingOptions preprocessing = const PreprocessingOptions(), String encoding = 'utf-8', bool debug = false, List<String> stripTags = const [], List<String> preserveTags = const [], bool skipImages = false, LinkStyle linkStyle = LinkStyle.inlined, OutputFormat outputFormat = OutputFormat.standard, bool includeDocumentStructure = false, bool extractImages = false, int maxImageSize = 5242880, bool captureSvg = false, bool inferDimensions = false, int? maxDepth, List<String> excludeSelectors = const []}) -
ConversionOptions.fromJson(Map<
String, dynamic> json) -
factory
Properties
- autolinks ↔ bool
-
getter/setter pair
- brInTables ↔ bool
-
getter/setter pair
- bullets ↔ String
-
getter/setter pair
- captureSvg ↔ bool
-
getter/setter pair
- codeBlockStyle ↔ CodeBlockStyle
-
getter/setter pair
- codeLanguage ↔ String
-
getter/setter pair
- convertAsInline ↔ bool
-
getter/setter pair
- debug ↔ bool
-
getter/setter pair
- defaultTitle ↔ bool
-
getter/setter pair
- encoding ↔ String
-
getter/setter pair
- escapeAscii ↔ bool
-
getter/setter pair
- escapeAsterisks ↔ bool
-
getter/setter pair
- escapeMisc ↔ bool
-
getter/setter pair
- escapeUnderscores ↔ bool
-
getter/setter pair
-
excludeSelectors
↔ List<
String> -
getter/setter pair
- extractImages ↔ bool
-
getter/setter pair
- extractMetadata ↔ bool
-
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- headingStyle ↔ HeadingStyle
-
getter/setter pair
- highlightStyle ↔ HighlightStyle
-
getter/setter pair
- includeDocumentStructure ↔ bool
-
getter/setter pair
- inferDimensions ↔ bool
-
getter/setter pair
-
keepInlineImagesIn
↔ List<
String> -
getter/setter pair
- linkStyle ↔ LinkStyle
-
getter/setter pair
- listIndentType ↔ ListIndentType
-
getter/setter pair
- listIndentWidth ↔ int
-
getter/setter pair
- maxDepth ↔ int?
-
getter/setter pair
- maxImageSize ↔ int
-
getter/setter pair
- newlineStyle ↔ NewlineStyle
-
getter/setter pair
- outputFormat ↔ OutputFormat
-
getter/setter pair
- preprocessing ↔ PreprocessingOptions
-
getter/setter pair
-
preserveTags
↔ List<
String> -
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- skipImages ↔ bool
-
getter/setter pair
- stripNewlines ↔ bool
-
getter/setter pair
-
stripTags
↔ List<
String> -
getter/setter pair
- strongEmSymbol ↔ String
-
getter/setter pair
- subSymbol ↔ String
-
getter/setter pair
- supSymbol ↔ String
-
getter/setter pair
- whitespaceMode ↔ WhitespaceMode
-
getter/setter pair
- wrap ↔ bool
-
getter/setter pair
- wrapWidth ↔ int
-
getter/setter pair
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited