PreprocessingOptions class

Preprocessing configuration for HTML cleanup before conversion.

Constructors

PreprocessingOptions({bool enabled = false, String preset = 'Standard', bool removeNavigation = false, bool removeForms = false})
const
PreprocessingOptions.fromJson(Map<String, dynamic> json)
factory

Properties

enabled → bool
final
hashCode → int
The hash code for this object.
no setterinherited
preset → String
final
removeForms → bool
final
removeNavigation → bool
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited