ConversionResult class

Constructors

ConversionResult({String? content, dynamic document, HtmlMetadata? metadata, List<Map<String, dynamic>> tables = const [], List<String> images = const [], List<ProcessingWarning> warnings = const []})
const
ConversionResult.fromJson(Map<String, dynamic> json)
factory

Properties

content String?
final
document → dynamic
final
hashCode int
The hash code for this object.
no setterinherited
images List<String>
final
metadata HtmlMetadata?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
tables List<Map<String, dynamic>>
final
warnings List<ProcessingWarning>
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited