HtmlMetadata class

Extracted HTML metadata from document head and body.

The Rust core outputs metadata with a nested document key containing the page-level metadata (title, description, etc.).

Constructors

HtmlMetadata({String? title, String? description, String? author, String? date, String? language, List<String> keywords = const [], String? canonicalUrl, String? baseHref, List<LinkMetadata> links = const [], List<ImageMetadata> images = const [], List<Map<String, dynamic>> structuredData = const []})
const
HtmlMetadata.fromJson(Map<String, dynamic> json)
factory

Properties

author String?
final
baseHref String?
final
canonicalUrl String?
final
date String?
final
description String?
final
hashCode int
The hash code for this object.
no setterinherited
images List<ImageMetadata>
final
keywords List<String>
final
language String?
final
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
structuredData List<Map<String, dynamic>>
final
title String?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited