ImageMetadata class

Constructors

ImageMetadata({String? src, String? alt, String? title})
const
ImageMetadata.fromJson(Map<String, dynamic> json)
factory

Properties

alt String?
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
src String?
final
title String?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited