LinkMetadata class

Constructors

LinkMetadata({String? href, String? text, String? title, String? rel})
const
LinkMetadata.fromJson(Map<String, dynamic> json)
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
href String?
final
rel String?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
text String?
final
title String?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited