CodeBlockStyle enum

Code block rendering style.

Inheritance
Available extensions

Values

fenced → const CodeBlockStyle
indented → const CodeBlockStyle

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
toJson String
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

fromJson(String value) CodeBlockStyle

Constants

values → const List<CodeBlockStyle>
A constant List of the values in this enum, in order of their declaration.