NativeLibrary class
Constructors
- NativeLibrary()
-
factory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
-
htmConversionOptionsFree
→ void Function(Pointer<
HTMConversionOptions> ptr) -
latefinal
-
htmConversionOptionsFromJson
→ Pointer<
HTMConversionOptions> Function(Pointer<Utf8> json) -
latefinal
-
htmConversionResultFree
→ void Function(Pointer<
HTMConversionResult> ptr) -
latefinal
-
htmConversionResultToJson
→ Pointer<
Utf8> Function(Pointer<HTMConversionResult> ptr) -
latefinal
-
htmConvert
→ Pointer<
HTMConversionResult> Function(Pointer<Utf8> html, Pointer<HTMConversionOptions> options) -
latefinal
-
htmFreeString
→ void Function(Pointer<
Utf8> ptr) -
latefinal
-
htmHtmHtmlVisitorBridgeFree
→ void Function(Pointer<
HTMHtmHtmlVisitorBridge> ptr) -
latefinal
-
htmHtmHtmlVisitorBridgeNew
→ Pointer<
HTMHtmHtmlVisitorBridge> Function(Pointer<HTMHtmHtmlVisitorVTable> vtable, Pointer<Void> userData) -
latefinal
- htmLastErrorCode → int Function()
-
latefinal
-
htmLastErrorContext
→ Pointer<
Utf8> Function() -
latefinal
-
htmOptionsSetVisitor
→ void Function(Pointer<
HTMConversionOptions> options, Pointer<HTMHtmHtmlVisitorBridge> visitor) -
latefinal
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
downloadIfNeeded(
) → Future< bool>