NodeContext class

Context information passed to each visitor callback.

Constructors

NodeContext({required NodeType nodeType, required String tagName, required int depth, required int indexInParent, String? parentTag, required bool isInline})
const

Properties

depth → int
final
hashCode → int
The hash code for this object.
no setterinherited
indexInParent → int
final
isInline → bool
final
nodeType → NodeType
final
parentTag → String?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
tagName → String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited