HTMHtmHtmlVisitorVTable class final

Simplified VTable for visitor callbacks (JSON context, single out-result). This is the preferred visitor interface for language bindings.

Inheritance
Implemented types
Available extensions

Constructors

HTMHtmHtmlVisitorVTable()

Properties

address → Pointer<T>

Available on T, provided by the StructAddress extension

The memory address of the underlying data.
no setter
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
visitElementEnd ↔ Pointer<NativeFunction<Int32 Function(Pointer<Void>, Pointer<Utf8>, Pointer<Utf8>, Pointer<Pointer<Utf8>>)>>
getter/setter pair
visitElementStart ↔ Pointer<NativeFunction<Int32 Function(Pointer<Void>, Pointer<Utf8>, Pointer<Pointer<Utf8>>)>>
getter/setter pair
visitImage ↔ Pointer<NativeFunction<Int32 Function(Pointer<Void>, Pointer<Utf8>, Pointer<Utf8>, Pointer<Utf8>, Pointer<Utf8>, Pointer<Pointer<Utf8>>)>>
getter/setter pair
getter/setter pair
visitText ↔ Pointer<NativeFunction<Int32 Function(Pointer<Void>, Pointer<Utf8>, Pointer<Utf8>, Pointer<Pointer<Utf8>>)>>
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited